@@ -1,9 +1,9 @@
 import unittest
-from helpsk import ExampleClass
+from helpsk.example_class import ExampleClass
 
 
 # noinspection PyMethodMayBeStatic
 class TestExampleClass(unittest.TestCase):
     def test_something(self):
         example = ExampleClass()
-        assert example.my_variable == 0
+        self.assertEqual(example.my_variable, 0)
